@@ -227,5 +227,22 @@ def AI_chat(text,is_speak=False,mode=5):
     else:
         if res_dict['ret'] == 16394:
             return 404
+def getversion():
+    return "0.4.5"
+def cleardevice():
+    print("\033[2J")
+    print("\033[99999999999999999999999999999999A", end='')
+def searchweb(text,title):
+    from cefpython3 import cefpython as cef
+    import platform
+    import sys
+    try:
+        html = urllib.request.urlopen(text).read().decode("utf-8")
+        sys.excepthook = cef.ExceptHook
+        cef.Initialize()
+        cef.CreateBrowserSync(url=text,window_title=title)
+        cef.MessageLoop()
+    except:
+        return -1
 def help():
     print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt").read().decode('gbk'))
\ No newline at end of file
